==> chromium_89.0.4389.114.orig.tar.xz: chromium-89.0.4389.114/chrome/browser/chromeos/printing/printing_stubs.h <==
// Copyright 2019 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROME_BROWSER_CHROMEOS_PRINTING_PRINTING_STUBS_H_
#define CHROME_BROWSER_CHROMEOS_PRINTING_PRINTING_STUBS_H_

#include <string>
#include <vector>

#include "base/optional.h"
#include "chrome/browser/chromeos/printing/cups_printers_manager.h"
#include "chrome/browser/chromeos/printing/printer_configurer.h"
#include "chromeos/printing/ppd_provider.h"
#include "chromeos/printing/printer_configuration.h"

namespace chromeos {

class StubCupsPrintersManager : public CupsPrintersManager {
 public:
  StubCupsPrintersManager() = default;

  std::vector<Printer> GetPrinters(PrinterClass printer_class) const override;
  bool IsPrinterInstalled(const Printer& printer) const override;
  base::Optional<Printer> GetPrinter(const std::string& id) const override;
  PrintServersManager* GetPrintServersManager() const override;

  void SavePrinter(const Printer& printer) override {}
  void RemoveSavedPrinter(const std::string& printer_id) override {}
  void AddObserver(CupsPrintersManager::Observer* observer) override {}
  void RemoveObserver(CupsPrintersManager::Observer* observer) override {}
  void PrinterInstalled(const Printer& printer, bool is_automatic) override {}
  void PrinterIsNotAutoconfigurable(const Printer& printer) override {}
  void RecordSetupAbandoned(const Printer& printer) override {}
  void FetchPrinterStatus(const std::string& printer_id,
                          PrinterStatusCallback cb) override {}
  void RecordNearbyNetworkPrinterCounts() const override {}
};

class StubPrinterConfigurer : public PrinterConfigurer {
 public:
  void SetUpPrinter(const Printer& printer,
                    PrinterSetupCallback callback) override {}
};

}  // namespace chromeos

#endif  // CHROME_BROWSER_CHROMEOS_PRINTING_PRINTING_STUBS_H_

==> chromium-93.0.4537.0.tar.xz: chromium-93.0.4537.0/chrome/browser/chromeos/printing/printing_stubs.h <==
// Copyright 2019 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROME_BROWSER_CHROMEOS_PRINTING_PRINTING_STUBS_H_
#define CHROME_BROWSER_CHROMEOS_PRINTING_PRINTING_STUBS_H_

#include <string>
#include <vector>

#include "chrome/browser/chromeos/printing/cups_printers_manager.h"
#include "chrome/browser/chromeos/printing/printer_configurer.h"
#include "chromeos/printing/ppd_provider.h"
#include "chromeos/printing/printer_configuration.h"
#include "third_party/abseil-cpp/absl/types/optional.h"

namespace chromeos {

class StubCupsPrintersManager : public CupsPrintersManager {
 public:
  StubCupsPrintersManager() = default;

  std::vector<Printer> GetPrinters(PrinterClass printer_class) const override;
  bool IsPrinterInstalled(const Printer& printer) const override;
  absl::optional<Printer> GetPrinter(const std::string& id) const override;
  PrintServersManager* GetPrintServersManager() const override;

  void SavePrinter(const Printer& printer) override {}
  void RemoveSavedPrinter(const std::string& printer_id) override {}
  void AddObserver(CupsPrintersManager::Observer* observer) override {}
  void RemoveObserver(CupsPrintersManager::Observer* observer) override {}
  void PrinterInstalled(const Printer& printer, bool is_automatic) override {}
  void PrinterIsNotAutoconfigurable(const Printer& printer) override {}
  void RecordSetupAbandoned(const Printer& printer) override {}
  void FetchPrinterStatus(const std::string& printer_id,
                          PrinterStatusCallback cb) override {}
  void RecordNearbyNetworkPrinterCounts() const override {}
};

class StubPrinterConfigurer : public PrinterConfigurer {
 public:
  void SetUpPrinter(const Printer& printer,
                    PrinterSetupCallback callback) override {}
};

}  // namespace chromeos

#endif  // CHROME_BROWSER_CHROMEOS_PRINTING_PRINTING_STUBS_H_
